Module pass

Module pass 

Optimization pass trait definition.

All optimization passes implement this trait, allowing them to be composed in a pipeline and run until a fixed point is reached.

Traits

Pass
Trait for MIR optimization passes.