LiveRange

Struct LiveRange 

pub struct LiveRange {
    pub start: usize,
    pub end: usize,
}
A live range interval [start, end) for a virtual register.

Fields

start: usize

First instruction index where the value is defined.

end: usize

Last instruction index where the value is used (inclusive).

Implementations

Source

impl LiveRange

pub fn overlaps(&self, other: &Self) -> bool

Returns true if this live range overlaps with another.

pub fn length(&self) -> usize

Returns the length of this live range.