Common subexpression elimination pass.
For each instruction, checks if an equivalent computation with the same operands already exists. If so, replaces the redundant computation with a reference to the existing value.
Structs
- Cse
- Common subexpression elimination pass.