Live range computation for virtual registers.
Computes the program points where each virtual register is live, represented as intervals over instruction indices in the flat LIR.
Structs
- Live
Range - A live range interval [start, end) for a virtual register.
Functions
- collect_
vregs - Collect all virtual registers used in the instruction sequence.
- compute_
live_ ranges - Compute live ranges for all virtual registers in a LIR instruction sequence.